<div id="top"></div>

<br/>
<div align="center">
  <a href="https://github.com/BornPaster/lumina">
    <img src="http://femboys.site/images/7b3659abb66043e59d5579939d9e3d1efad513589e4145298921f022611a485a.png" alt="Logo" >
  </a>
  
  <h2 align="center">Lumina™</h3>

  <p align="center">
    Clean And Very Lightweight Logging Library.
    <br />
    <br />
    <a href="https://github.com/BornPaster/lumina/issues">Report Bug</a>
    ·
    <a href="https://github.com/BornPaster/lumina/issues">Request Feature</a>
  </p>
</div>
  
---------------------------------------

### Features
* Extremely Lightweight.
* Clean And Simple.
* Can Be Used For Any Color Scheme.
* Input And Print Accessability. 

---------------------------------------

### Requirements
* Windows OS | Linux
* Python 3.6+

---------------------------------------

### Usage
* Installation:
```pip install luminalog```

* Print Type:
```py
from lumina import *

lumina = core()

lumina.consolelog("Hi, I'm Lumina!", type="print")
```

* Input Type:
```py
from lumina import *

lumina = core()

lumina.consolelog("Hi, I'm Lumina, What's Your Name: ", type="input")
```

---------------------------------------

### Extra
* fully made by zappy // i am the only developer for this library.
* library fully open source and can be used by anyone.
* the library code is fully made by me. if anyone pastes it, there will be consequences.
